#ifndef AIRENCE_API_H
#define AIRENCE_API_H

#if defined(AIRENCE_STATIC_LIB)
	#define AIRENCE_API
#elif defined(AIRENCE_DLL)
    #define AIRENCE_API __declspec(dllexport)
#else
   #define AIRENCE_API __declspec(dllimport)
#endif

/* Control signals */
#define LED_ALL				0xFF
#define	SW_LED_1			1
#define SW_LED_2			2 
#define SW_LED_3			3	 
#define SW_LED_4			4 
#define SW_LED_5			5 
#define SW_LED_6			6
#define SW_LED_7			7 
#define SW_LED_8			8
#define SW_LED_9			9	 
#define SW_LED_10			10 
#define SW_LED_11			11 
#define SW_LED_12			12 
#define SW_LED_13			13 
#define SW_LED_14			14
#define SW_LED_15			15
#define SW_LED_16			16
#define SW_LED_17			17
#define SW_LED_18			18 
#define SW_LED_19			19 
#define SW_LED_20			20
#define SW_LED_21			21
#define SW_LED_22			22 
#define SW_LED_23			23
#define SW_LED_24			24
#define SW_ENCODER			25
#define SW_NONSTOP			26
#define SW_USB1_FADERSTART	27
#define SW_USB1_ON			28
#define SW_USB1_CUE			29
#define SW_USB2_FADERSTART	30
#define SW_USB2_ON			31
#define SW_USB2_CUE			32
#define SW_USB3_FADERSTART	33
#define SW_USB3_ON			34
#define SW_USB3_CUE			35
#define SW_USB4_FADERSTART	36
#define SW_USB4_ON			37
#define SW_USB4_CUE			38

/* LED colors */
typedef enum {
	NONE, 
	RED, 
	GREEN,
	YELLOW
} colors_t;

/* LED blink speed */
typedef enum {
	SLOW,
	NORMAL,
	FAST
} blink_speed_t;


#ifdef __cplusplus
extern "C" {
#endif

	/* Returns 0 on succes, otherwise -1 */
	AIRENCE_API int airenceOpen( void );

	/* Returns 0 on succes, otherwise -1 */
	AIRENCE_API int airenceClose( void );

	/* Returns 0 on succes, otherwise -1 */
	AIRENCE_API int airenceSetLed( int lednr, colors_t color );

	/* Returns 0 on succes, otherwise -1 */
	AIRENCE_API int airenceSetLedBlink( int lednr, colors_t on, colors_t off, blink_speed_t speed );

	/* Returns 0 on succes, otherwise -1 */
	AIRENCE_API int airenceGetControlSignal( int controlsignal, bool *state );

	/* Returns 0 on succes, otherwise -1 */
	AIRENCE_API int airenceGetRawControlData( unsigned char *data );
	
	/* Returns version of this Airence API library */
	AIRENCE_API char* airenceGetLibraryVersion( int* major, int* minor );

	/* Returns version of Airence firmware */
	AIRENCE_API char* airenceGetFirmwareVersion( int* major, int* minor );

	/* Callback register functions */
	AIRENCE_API void airenceSetControlSignalChangeCB( void(*CSC_CB)(int controlsignal, bool state, void *data), void *data );
	AIRENCE_API void airenceClearControlSignalChangeCB( void );
	AIRENCE_API void airenceSetEncoderChangeCB( void(*EC_CB)( int direction, unsigned char abs_value, void *data), void *data );
	AIRENCE_API void airenceClearEncoderChangeCB( void );


	/* * * F U N C T I O N S   A D D E D   I N   V 1.2  * * */
	AIRENCE_API void airenceSetReadMode(int readmode);
	/* readmode value:
	 -1: Blocking
	  0: Non-Blocking 
	 >0: Non-Blocking with timeout in ms */
	AIRENCE_API char* airenceGetLastError(void);
	AIRENCE_API void airenceEnableLogging(bool);

#ifdef __cplusplus
}
#endif

#endif
